#pragma once
#define GIT_COMMIT_HASH    "a0136d8c04687bb36eb8a28eb9d1ff92aea99704"
#define GIT_BRANCH         "v0.55.4"
#define GIT_COMMIT_MESSAGE "[gha] Nix: update inputs"
#define GIT_COMMIT_DATE    "Thu Jun 11 17:10:04 2026"
#define GIT_DIRTY          "clean"
#define GIT_TAG            "v0.55.4"
#define GIT_COMMITS        "7378"

#define AQUAMARINE_VERSION "0.12.1"
// clang-format off
#define AQUAMARINE_VERSION_MAJOR 0
#define AQUAMARINE_VERSION_MINOR 12
#define AQUAMARINE_VERSION_PATCH 1
// clang-format on
#define HYPRLANG_VERSION     "0.6.8"
#define HYPRUTILS_VERSION    "0.13.1"
#define HYPRCURSOR_VERSION   "0.1.13"
#define HYPRGRAPHICS_VERSION "0.5.1"
